@@ -173,7 +173,7 @@ class DepsGraph(object):
                     conanfile.package_id()
         return ordered
 
-    def full_closure(self, node):
+    def full_closure(self, node, private=False):
         # Needed to propagate correctly the cpp_info even with privates
         closure = OrderedDict()
         current = node.neighbors()
@@ -182,7 +182,8 @@ class DepsGraph(object):
             for n in current:
                 closure[n] = n
             for n in current:
-                for neigh in n.public_neighbors():
+                neighbors = n.public_neighbors() if not private else n.neighbors()
+                for neigh in neighbors:
                     if neigh not in new_current and neigh not in closure:
                         new_current.append(neigh)
             current = new_current
