@@ -15,10 +15,6 @@ class ConanFileLoader(object):
     def __init__(self, runner, settings, profile):
         """
         @param settings: Settings object, to assign to ConanFile at load time
-        @param options: OptionsValues, necessary so the base conanfile loads the options
-                        to start propagation, and having them in order to call build()
-        @param package_settings: Dict with {recipe_name: {setting_name: setting_value}}
-        @param cached_env_values: EnvValues object
         """
         self._runner = runner
 
