@@ -285,9 +285,8 @@ class ConanManager(object):
             for node in deps_graph.nodes:
                 if not node.conan_ref:
                     continue
-                conanfile = node.conanfile
                 complete_recipe_sources(self._remote_manager, self._client_cache, self._registry,
-                                        conanfile, node.conan_ref)
+                                        node.conanfile, node.conan_ref)
             manifest_manager.check_graph(deps_graph,
                                          verify=manifest_verify,
                                          interactive=manifest_interactive)
@@ -358,7 +357,8 @@ class ConanManager(object):
                                 install_folder, output, local=True, copy_info=True)
 
     def build(self, conanfile_path, source_folder, build_folder, package_folder, install_folder,
-              test=False, should_configure=True, should_build=True, should_install=True):
+              test=False, should_configure=True, should_build=True, should_install=True,
+              should_test=True):
         """ Call to build() method saved on the conanfile.py
         param conanfile_path: path to a conanfile.py
         """
@@ -387,6 +387,7 @@ class ConanManager(object):
         conan_file.should_configure = should_configure
         conan_file.should_build = should_build
         conan_file.should_install = should_install
+        conan_file.should_test = should_test
 
         try:
             mkdir(build_folder)
