@@ -16,7 +16,8 @@ class MSBuildTest(unittest.TestCase):
     def dont_mess_with_build_type_test(self):
         settings = MockSettings({"build_type": "Debug",
                                  "compiler": "Visual Studio",
-                                 "arch": "x86_64"})
+                                 "arch": "x86_64",
+                                 "compiler.runtime": "MDd"})
         conanfile = MockConanfile(settings)
         msbuild = MSBuild(conanfile)
         self.assertEquals(msbuild.build_env.flags, ["-Zi", "-Ob0", "-Od"])
@@ -30,6 +31,16 @@ class MSBuildTest(unittest.TestCase):
 
         self.assertNotIn("-Ob0", template)
         self.assertNotIn("-Od", template)
+        self.assertIn("<RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>", template)
+
+    def without_runtime_test(self):
+        settings = MockSettings({"build_type": "Debug",
+                                 "compiler": "Visual Studio",
+                                 "arch": "x86_64"})
+        conanfile = MockConanfile(settings)
+        msbuild = MSBuild(conanfile)
+        template = msbuild._get_props_file_contents()
+        self.assertNotIn("<RuntimeLibrary>", template)
 
     @attr('slow')
     def build_vs_project_test(self):
@@ -99,3 +110,34 @@ class HelloConan(ConanFile):
         client.run("install Hello/1.2.1@lasote/stable --build -s arch=x86 -s build_type=Debug")
         self.assertIn("Debug|x86", client.user_io.out)
         self.assertIn("Copied 1 '.exe' file: MyProject.exe", client.user_io.out)
+
+    def reuse_msbuild_object_test(self):
+        # https://github.com/conan-io/conan/issues/2865
+        if platform.system() != "Windows":
+            return
+        conan_build_vs = """
+from conans import ConanFile, MSBuild
+
+class HelloConan(ConanFile):
+    name = "Hello"
+    version = "1.2.1"
+    exports = "*"
+    settings = "os", "build_type", "arch", "compiler", "cppstd"
+
+    def configure(self):
+        del self.settings.compiler.runtime
+        del self.settings.build_type
+
+    def build(self):
+        msbuild = MSBuild(self)
+        msbuild.build("MyProject.sln", build_type="Release")
+        msbuild.build("MyProject.sln", build_type="Debug")
+        self.output.info("build() completed")
+"""
+        client = TestClient()
+        files = get_vs_project_files()
+        files[CONANFILE] = conan_build_vs
+
+        client.save(files)
+        client.run("create . danimtb/testing")
+        self.assertIn("build() completed", client.out)
