@@ -43,6 +43,7 @@ class Conan(ConanFile):
         self.output.info("CONFIGURE=%s!" % self.should_configure)
         self.output.info("BUILD=%s!" % self.should_build)
         self.output.info("INSTALL=%s!" % self.should_install)
+        self.output.info("TEST=%s!" % self.should_test)
 """
         client.save({CONANFILE: conanfile})
         client.run("install .")
@@ -50,23 +51,33 @@ class Conan(ConanFile):
         self.assertIn("CONFIGURE=True!", client.out)
         self.assertIn("BUILD=True!", client.out)
         self.assertIn("INSTALL=True!", client.out)
+        self.assertIn("TEST=True!", client.out)
         client.run("build . -c")
         self.assertIn("CONFIGURE=True!", client.out)
         self.assertIn("BUILD=False!", client.out)
         self.assertIn("INSTALL=False!", client.out)
+        self.assertIn("TEST=False!", client.out)
         client.run("build . -b")
         self.assertIn("CONFIGURE=False!", client.out)
         self.assertIn("BUILD=True!", client.out)
         self.assertIn("INSTALL=False!", client.out)
+        self.assertIn("TEST=False!", client.out)
         client.run("build . -i")
         self.assertIn("CONFIGURE=False!", client.out)
         self.assertIn("BUILD=False!", client.out)
         self.assertIn("INSTALL=True!", client.out)
+        self.assertIn("TEST=False!", client.out)
+        client.run("build . -t")
+        self.assertIn("CONFIGURE=False!", client.out)
+        self.assertIn("BUILD=False!", client.out)
+        self.assertIn("INSTALL=False!", client.out)
+        self.assertIn("TEST=True!", client.out)
 
         client.run("create . Pkg/0.1@user/testing")
         self.assertIn("CONFIGURE=True!", client.out)
         self.assertIn("BUILD=True!", client.out)
         self.assertIn("INSTALL=True!", client.out)
+        self.assertIn("TEST=True!", client.out)
 
     def build_error_test(self):
         """ If not using -g txt generator, and build() requires self.deps_cpp_info,
