@@ -49,14 +49,13 @@ class MultiRemotesTest(unittest.TestCase):
 
         # Execute info method in client_b, should advise that there is an update
         client_b.run("info Hello0/0.0@lasote/stable -u")
-        self.assertIn("Updates: There is a newer version (local)", str(client_b.user_io.out))
+        self.assertIn("Recipe: Update available", client_b.out)
+        self.assertIn("Binary: Cache", client_b.out)
 
         # Now try to update the package with install -u
         client_b.run("remote list_ref")
         self.assertIn("Hello0/0.0@lasote/stable: local", str(client_b.user_io.out))
         client_b.run("install Hello0/0.0@lasote/stable -u --build")
-        self.assertIn("Hello0/0.0@lasote/stable: Retrieving from remote 'local'",
-                      str(client_b.user_io.out))
         client_b.run("remote list_ref")
         self.assertIn("Hello0/0.0@lasote/stable: local", str(client_b.user_io.out))
 
@@ -68,20 +67,19 @@ class MultiRemotesTest(unittest.TestCase):
 
         # Now client_b checks for updates without -r parameter
         client_b.run("info Hello0/0.0@lasote/stable -u")
-        self.assertIn("Remote: local", str(client_b.user_io.out))
-        self.assertIn("You have the latest version (local)", str(client_b.user_io.out))
+        self.assertIn("    Remote: local", str(client_b.user_io.out))
+        self.assertIn("    Recipe: Cache", client_b.out)
 
         # But if we connect to default, should tell us that there is an update IN DEFAULT!
         client_b.run("info Hello0/0.0@lasote/stable -r default -u")
         self.assertIn("Remote: local", str(client_b.user_io.out))
-        self.assertIn("There is a newer version (default)", str(client_b.user_io.out))
         client_b.run("remote list_ref")
         self.assertIn("Hello0/0.0@lasote/stable: local", str(client_b.user_io.out))
 
         # Well, now try to update the package with -r default -u
         client_b.run("install Hello0/0.0@lasote/stable -r default -u --build")
-        self.assertIn("Hello0/0.0@lasote/stable: Retrieving from remote 'default'",
+        self.assertIn("Hello0/0.0@lasote/stable: Calling build()",
                       str(client_b.user_io.out))
         client_b.run("info Hello0/0.0@lasote/stable -u")
-        self.assertIn("Updates: You have the latest version (default)",
-                      str(client_b.user_io.out))
+        self.assertIn("Recipe: Cache", client_b.out)
+        self.assertIn("Binary: Cache", client_b.out)
